@@ -22,7 +22,10 @@ LOG_LEVEL = logging.INFO  ## (logging.INFO)
 ## When testing user-supplied snippets watch out for the BOM MS inserts via Notepad. AST chokes on it.
 ## All snippets here should be raw strings (see https://stackoverflow.com/questions/53636723/python-parsing-code-with-new-line-character-in-them-using-ast)
 TEST_SNIPPET = r"""
-age = 21
+msgs = []
+for i in range(20):
+    msgs.append(f"i is {i}")
+name = 'Grant'
 """
 
 PY3_6 = '3.6'
